import * as React from "react";
import { cva, type VariantProps } from "class-variance-authority";

import { cn } from "@/lib/utils";

// credit to https://ui.shadcn.com/docs/components/badge for the badge component
const badgeVariants = cva(
  "inline-flex items-center rounded-full border px-2.5 py-0.5 text-xs font-semibold transition-colors focus:outline-none focus:ring-2 focus:ring-ring focus:ring-offset-2",
  {
    variants: {
      variant: {
        default:
          "border-transparent bg-primary text-primary-foreground hover:bg-primary/80",
        secondary:
          "border-transparent bg-secondary text-secondary-foreground hover:bg-secondary/80",
        destructive:
          "border-transparent bg-destructive text-destructive-foreground hover:bg-destructive/80",
        outline: "text-foreground",
      },
    },
    defaultVariants: {
      variant: "outline",
    },
  }
);

export interface BadgeProps
  extends React.HTMLAttributes<HTMLDivElement>,
    VariantProps<typeof badgeVariants> {
  badgeColor?: string;
}

function Badge({ className, badgeColor, variant, ...props }: BadgeProps) {
  return (
    <div
      className={cn(
        badgeVariants({ variant }),
        badgeColor && `text-${badgeColor} border-${badgeColor}`,
        className
      )}
      {...props}
    />
  );
}

interface BadgeCollectionProps extends BadgeProps {
  badges: string[];
}

function BadgeCollection({ badges, ...props }: BadgeCollectionProps) {
  return (
    <div className="flex flex-wrap gap-2">
      {badges.map((badge) => (
        <Badge key={badge} {...props}>
          {badge}
        </Badge>
      ))}
    </div>
  );
}

export { Badge, BadgeCollection, badgeVariants };
